#!/usr/bin/python
"""
###############################################################
Digital Loggers Web Power Switch management
###############################################################
 Description: This is both a module and a script

              The module provides a python class named
              powerswitch that allows managing the web power
              switch from python programs.

              When run as a script this acts as a command
              line utility to manage the DLI Power switch.
 Author: Dwight Hubbard d@dhub.me
 Copyright: This module may be used for any use personal
            or commercial as long as the author and copyright
            notice are included in full.
"""

# Python built in modules
import os
import sys
import time
import optparse
import base64
import json
import urllib2

# External modules
import BeautifulSoup

# Global settings
TIMEOUT=5
CYCLETIME=3
CONFIG_DEFAULTS={'timeout':TIMEOUT,'cycletime':CYCLETIME,'userid':'admin','password':'4321','hostname':'192.168.0.100'}
CONFIG_FILE=os.path.expanduser('~/.dlipower.conf')

class powerswitch:
    """ Powerswitch class to manage the Digital Loggers Web power switch """
    def __init__(self,userid=None,password=None,hostname=None,timeout=None,cycletime=None):
        CONFIG=self.load_configuration()
        if userid:
            self.userid=userid
        else:
            self.userid=CONFIG['userid']
        if password:
            self.password=password
        else:
            self.password=CONFIG['password']
        if hostname:
            self.hostname=hostname
        else:
            self.hostname=CONFIG['hostname']
        if timeout:
            self.timeout=float(timeout)
        else:
            self.timeout=CONFIG['timeout']
        if cycle_time:
            self.cycle_time=float(cycle_time)
        else:
            self.cycle_time=CONFIG['cycletime']
    def load_configuration(self):
        """ Return a configuration dictionary """
        if os.path.isfile(CONFIG_FILE):
            fh=open(CONFIG_FILE,'r')
            try:
              CONFIG=json.load(fh)
            except ValueError:
              # Failed
              return CONFIG_DEFAULTS
            fh.close()
            return CONFIG
        return CONFIG_DEFAULTS
    def save_configuration(self):
        """ Update the configuration file with the object's settings """
        # Get the configuration from the config file or set to the defaults
        CONFIG=self.load_configuration()
            
        # Overwrite the objects configuration over the existing config values
        CONFIG['userid']=self.userid
        CONFIG['password']=self.password
        CONFIG['hostname']=self.hostname
        CONFIG['timeout']=self.timeout
        
        # Write it to disk
        fh=open(CONFIG_FILE,'w')
        # Make sure the file perms are correct before we write data
        # that can include the password into it.
        os.fchmod(fh.fileno(),0o0600)
        if fh:
            json.dump(CONFIG,fh,sort_keys=True, indent=4)
            fh.close()
        else:
            return True
        return False
    def verify(self):
        """ Verify we can reach the switch, returns true if ok """
        return self.geturl()
    def geturl(self,url='index.htm') :
        """ Get a URL from the userid/password protected powerswitch page 
            Return None on failure
        """
        request = urllib2.Request("http://%s/%s" % (self.hostname,url))
        base64string = base64.encodestring('%s:%s' % (self.userid, self.password)).replace('\n', '')
        request.add_header("Authorization", "Basic %s" % base64string)   
        try:
            result = urllib2.urlopen(request,timeout=self.timeout).read()
        except urllib2.URLError:
            return None
        #except timeout:
        #    return None
        return result
    def off(self,outlet=0):
        """ Turn off a power to an outlet 
            False = Success
            True = Fail
        """
        self.geturl(url= 'outlet?%d=OFF' % outlet)
        return self.status(outlet) != 'OFF'
    def on(self,outlet=0):
        """ Turn on power to an outlet 
            False = Success
            True = Fail
        """
        self.geturl(url= 'outlet?%d=ON' % outlet)
        return self.status(outlet) != 'ON'
    def cycle(self,outlet=0):
        """ Cycle power to an outlet 
            False = Success
            True = Fail
        """        
        start_status=self.status(outlet)
        if start_status == 'OFF':
          return False
        if start_status == 'Unknown':
          return True
        else:
          if self.off(outlet):
            return True
          time.sleep(CYCLETIME)
          if self.on(outlet):
            return True
        return self.status(outlet) != start_status
    def statuslist(self):
        """ Return the status of all outlets in a list, 
        each item will contain 3 items plugnumber, hostname and state  """
        outlets=[]
        url=self.geturl('index.htm')
        if not url:
            return None
        soup=BeautifulSoup.BeautifulSoup(url)
        # Get the root of the table containing the port status info
        try:
            root=soup.findAll('td',text='1')[0].parent.parent.parent
        except IndexError:
            return None
        for temp in root.findAll('tr'):
            columns=temp.findAll('td')
            if len(columns) == 5:
                plugnumber=columns[0].string
                hostname=columns[1].string
                state=columns[2].find('font').string.upper()
                outlets.append([int(plugnumber),hostname,state])
        return outlets
    def printstatus(self):
        """ Print the status off all the outlets as a table to stdout """
        if not self.statuslist():
            print("Unable to communicate to the Web power switch at %s" % self.hostname)
            return None
        print('Outlet\t%-15.15s\tState' % 'Hostname')
        for item in self.statuslist():
            print('%d\t%-15.15s\t%s' % (item[0],item[1],item[2]))
        return
    def status(self,outlet=1):
        """ Return the status of an outlet, returned value will be one of: ON, OFF, Unknown """
        outlets=self.statuslist()
        if outlets and outlet:
            for plug in outlets:
                if plug[0] == outlet:
                    return plug[2]
        return 'Unknown'

if __name__ == "__main__":
    usage = "usage: %prog [options] [status|on|off|cycle] [arg]"
    parser = optparse.OptionParser(usage=usage)
    parser.add_option('--hostname',dest='hostname',default=None,help="hostname/ip of the power switch (default %default)")
    parser.add_option('--timeout',dest='timeout',default=None,help="Timeout for value for power switch communication (default %default)")
    parser.add_option('--cycletime',dest='cycletime',default=None,type=int,help="Delay betwween off/on states for power cycle operations (default %default)")
    parser.add_option('--user',    dest='user',    default=None        ,help="userid to connect with (default %default)"         )
    parser.add_option('--password',dest='password',default=None         ,help="password (default %default)"                       )
    parser.add_option('--save_settings',dest='save_settings',default=False,action='store_true',help='Save the settings to the configuration file')
    (options, args) = parser.parse_args()

    switch=powerswitch(userid=options.user,password=options.password,hostname=options.hostname,timeout=options.timeout,cycletime=options.cycletime)
    if options.save_settings:
        switch.save_configuration()
    if len(args):
        if len(args) == 2:
            if args[0].lower() in ['on','poweron']:
                sys.exit(switch.on(int(args[1])))
            if args[0].lower() in ['off','poweroff']:
                sys.exit(switch.off(int(args[1])))
            if args[0].lower() in ['cycle']:
                sys.exit(switch.cycle(int(args[1])))
            if args[0].lower() in ['status']:
                print(switch.status(int(args[1])))
    else:
        switch.printstatus()



#!/usr/bin/env python
import unittest
import urllib
import urllib2
import StringIO
import os
import sys
sys.path.insert(0,'../dlipower')
import dlipower

__author__ = 'dhubbard'

OFF_HTML="""<html>
<head>
<META NAME="ROBOTS" CONTENT="NOINDEX, NOFOLLOW">

<META HTTP-EQUIV="Refresh" CONTENT="60">
<title>Outlet Control  - Home Theater</title>
<script language="JavaScript">
<!--
function reg() {
window.open('http://www.digital-loggers.com/register.html?SN=0000331011');
}
//-->
</script>
</head>
<!-- state=fe lock=00 -->

<body alink="#0000FF" vlink="#0000FF">
<FONT FACE="Arial, Helvetica, Sans-Serif">
<table width="100%" cellspacing=0 cellpadding=0>
<tr>
<td valign=top width="17%" height="100%">

    <!-- menu -->
    <table width="100%" height="100%" align=center border=0 cellspacing=1 cellpadding=0>
    <tr><td valign=top bgcolor="#F4F4F4">
    <table width="100%" cellpadding=1 cellspacing=5>

    <tr><td align=center>

    <table><tr><td><a href="http://www.digital-loggers.com/8.html"><img src=logo.gif width=195 height=65 border=0 alt="Digital Loggers, Inc"></a></td>

    <td><b><font size=-1>Ethernet Power Controller</font></b></td></tr></table>
    <hr>
    </td></tr>



<tr><td nowrap><b><a href="/index.htm">Outlet Control</a></b></td></tr>
<tr><td nowrap><b><a href="/admin.htm">Setup</a></b></td></tr>
<tr><td nowrap><b><a href="/script.htm">Scripting</a></b></td></tr>



<tr><td nowrap><b><a href="/rtc.htm">Date/Time</a></b></td></tr>

<tr><td nowrap><b><a href="/ap.htm">AutoPing</a></b></td></tr>
<tr><td nowrap><b><a href="/syslog.htm">System Log</a></b></td></tr>
<tr><td nowrap><b><a href="/logout">Logout</a></b></td></tr>
<tr><td nowrap><b><a href="/help/">Help</a></b></td></tr>

<tr><td><hr></td></tr>


<tr><td><b><a href="http://www.digital-loggers.com/5.html">Manual</a></b></td></tr>

<tr><td><b><a href="http://www.digital-loggers.com/6.html">FAQ</a></b></td></tr>

<tr><td><b><a href="http://www.digital-loggers.com/7.html">Product Information</a></b></td></tr>

<tr><td><b><a href="http://www.digital-loggers.com/8.html">Digital Logger Inc.</a></b></td></tr>


    </table>
    </td></tr>


    <tr><td valign=bottom height="100%" bgcolor="#F4F4F4">
    <small>Version 1.6.0 (Jun 22 2012 / 21:56:21) 8AA39795-EE789B21</small>
    </td></tr>
    <tr><td valign=bottom height="100%" bgcolor="#F4F4F4">
    <small>S/N:0000331011</small>
    </td></tr>

    </table>
    <!-- /menu -->

</td>
<td valign=top width="83%">

    <!-- heading table -->
    <table width="100%" align=center border=0 cellspacing=1 cellpadding=3>

        <tr>
        <th bgcolor="#DDDDFF" align=left>
        Controller: Home Theater
        </th>
        </tr>

        <tr bgcolor="#FFFFFF" align=left>
        <td>
        Fri Jul  6 07:08:51 2012 <!-- 1162615s up -->
        </td>
        </tr>

    </table>
    <!-- /heading table -->

    <br>

    <!-- individual control table -->
    <table width="100%" align=center border=0 cellspacing=1 cellpadding=3>

        <tr>
        <td bgcolor="#DDDDFF" colspan=5 align=left>
        Individual Control
        </td>
        </tr>

        <!-- heading rows -->
        <tr bgcolor="#DDDDDD">
        <th>#</th>
        <th align=left>Name</th>
        <th align=left>State</th>
        <th align=left colspan=2>Action</th>
        </tr>
        <!-- /heading rows -->




<tr bgcolor="#F4F4F4"><td align=center>1</td>
<td>Lights</td><td>
<b><font color=red>OFF</font></b></td><td>
<a  href=outlet?1=ON>Switch ON</a>
</td><td>
<!-- <a  href=outlet?1=CCL>Cycle</a> -->
</td></tr>


<tr bgcolor="#F4F4F4"><td align=center>2</td>
<td>Microwave</td><td>
<b><font color=green>ON</font></b></td><td>
<a onclick="return confirm('You are going to switch Outlet 2 [Microwave] OFF. Continue?')" href=outlet?2=OFF>Switch OFF</a>
</td><td>
<a onclick="return confirm('You are going to cycle Outlet 2 [Microwave]. Continue?')" href=outlet?2=CCL>Cycle</a>
</td></tr>


<tr bgcolor="#F4F4F4"><td align=center>3</td>
<td>NETHD</td><td>
<b><font color=green>ON</font></b></td><td>
<a onclick="return confirm('You are going to switch Outlet 3 [NETHD] OFF. Continue?')" href=outlet?3=OFF>Switch OFF</a>
</td><td>
<a onclick="return confirm('You are going to cycle Outlet 3 [NETHD]. Continue?')" href=outlet?3=CCL>Cycle</a>
</td></tr>


<tr bgcolor="#F4F4F4"><td align=center>4</td>
<td>WDTV</td><td>
<b><font color=green>ON</font></b></td><td>
<a onclick="return confirm('You are going to switch Outlet 4 [WDTV] OFF. Continue?')" href=outlet?4=OFF>Switch OFF</a>
</td><td>
<a onclick="return confirm('You are going to cycle Outlet 4 [WDTV]. Continue?')" href=outlet?4=CCL>Cycle</a>
</td></tr>


<tr bgcolor="#F4F4F4"><td align=center>5</td>
<td>PS3</td><td>
<b><font color=green>ON</font></b></td><td>
<a onclick="return confirm('You are going to switch Outlet 5 [PS3] OFF. Continue?')" href=outlet?5=OFF>Switch OFF</a>
</td><td>
<a onclick="return confirm('You are going to cycle Outlet 5 [PS3]. Continue?')" href=outlet?5=CCL>Cycle</a>
</td></tr>


<tr bgcolor="#F4F4F4"><td align=center>6</td>
<td>Popcorn Popper</td><td>
<b><font color=green>ON</font></b></td><td>
<a onclick="return confirm('You are going to switch Outlet 6 [Popcorn Popper] OFF. Continue?')" href=outlet?6=OFF>Switch OFF</a>
</td><td>
<a onclick="return confirm('You are going to cycle Outlet 6 [Popcorn Popper]. Continue?')" href=outlet?6=CCL>Cycle</a>
</td></tr>


<tr bgcolor="#F4F4F4"><td align=center>7</td>
<td>ITACH</td><td>
<b><font color=green>ON</font></b></td><td>
<a onclick="return confirm('You are going to switch Outlet 7 [ITACH] OFF. Continue?')" href=outlet?7=OFF>Switch OFF</a>
</td><td>
<a onclick="return confirm('You are going to cycle Outlet 7 [ITACH]. Continue?')" href=outlet?7=CCL>Cycle</a>
</td></tr>


<tr bgcolor="#F4F4F4"><td align=center>8</td>
<td>Life Support</td><td>
<b><font color=green>ON</font></b></td><td>
<a onclick="return confirm('You are going to switch Outlet 8 [Life Support] OFF. Continue?')" href=outlet?8=OFF>Switch OFF</a>
</td><td>
<a onclick="return confirm('You are going to cycle Outlet 8 [Life Support]. Continue?')" href=outlet?8=CCL>Cycle</a>
</td></tr>


    </table>
    <!-- /individual control table -->

    <br>

<table width="100%" align=center border=0 cellspacing=1 cellpadding=3>
<tr><td bgcolor="#DDDDFF" align=left>Master Control</td></tr>

<tr><td bgcolor="#F4F4F4" align=left><a onclick="return confirm('You are going to switch all Outlets OFF. Continue?')" href=outlet?a=OFF>All Outlets OFF</a></td></tr>
<tr><td bgcolor="#F4F4F4" align=left><a href=outlet?a=ON>All Outlets ON</a></td></tr>
<tr><td bgcolor="#F4F4F4" align=left><a onclick="return confirm('You are going to cycle all Outlets. Continue?')" href=outlet?a=CCL>Cycle all Outlets</a></td></tr>
<tr><td align=center>Sequence delay: 15 sec.</td></tr>

</table>


</td>
</tr>
</table>

</body>
</html>"""

ON_HTML="""<html>
<head>
<META NAME="ROBOTS" CONTENT="NOINDEX, NOFOLLOW">

<META HTTP-EQUIV="Refresh" CONTENT="60">
<title>Outlet Control  - Home Theater</title>
<script language="JavaScript">
<!--
function reg() {
window.open('http://www.digital-loggers.com/register.html?SN=0000331011');
}
//-->
</script>
</head>
<!-- state=ff lock=00 -->

<body alink="#0000FF" vlink="#0000FF">
<FONT FACE="Arial, Helvetica, Sans-Serif">
<table width="100%" cellspacing=0 cellpadding=0>
<tr>
<td valign=top width="17%" height="100%">

    <!-- menu -->
    <table width="100%" height="100%" align=center border=0 cellspacing=1 cellpadding=0>
    <tr><td valign=top bgcolor="#F4F4F4">
    <table width="100%" cellpadding=1 cellspacing=5>

    <tr><td align=center>

    <table><tr><td><a href="http://www.digital-loggers.com/8.html"><img src=logo.gif width=195 height=65 border=0 alt="Digital Loggers, Inc"></a></td>

    <td><b><font size=-1>Ethernet Power Controller</font></b></td></tr></table>
    <hr>
    </td></tr>



<tr><td nowrap><b><a href="/index.htm">Outlet Control</a></b></td></tr>
<tr><td nowrap><b><a href="/admin.htm">Setup</a></b></td></tr>
<tr><td nowrap><b><a href="/script.htm">Scripting</a></b></td></tr>



<tr><td nowrap><b><a href="/rtc.htm">Date/Time</a></b></td></tr>

<tr><td nowrap><b><a href="/ap.htm">AutoPing</a></b></td></tr>
<tr><td nowrap><b><a href="/syslog.htm">System Log</a></b></td></tr>
<tr><td nowrap><b><a href="/logout">Logout</a></b></td></tr>
<tr><td nowrap><b><a href="/help/">Help</a></b></td></tr>

<tr><td><hr></td></tr>


<tr><td><b><a href="http://www.digital-loggers.com/5.html">Manual</a></b></td></tr>

<tr><td><b><a href="http://www.digital-loggers.com/6.html">FAQ</a></b></td></tr>

<tr><td><b><a href="http://www.digital-loggers.com/7.html">Product Information</a></b></td></tr>

<tr><td><b><a href="http://www.digital-loggers.com/8.html">Digital Logger Inc.</a></b></td></tr>


    </table>
    </td></tr>


    <tr><td valign=bottom height="100%" bgcolor="#F4F4F4">
    <small>Version 1.6.0 (Jun 22 2012 / 21:56:21) 8AA39795-EE789B21</small>
    </td></tr>
    <tr><td valign=bottom height="100%" bgcolor="#F4F4F4">
    <small>S/N:0000331011</small>
    </td></tr>

    </table>
    <!-- /menu -->

</td>
<td valign=top width="83%">

    <!-- heading table -->
    <table width="100%" align=center border=0 cellspacing=1 cellpadding=3>

        <tr>
        <th bgcolor="#DDDDFF" align=left>
        Controller: Home Theater
        </th>
        </tr>

        <tr bgcolor="#FFFFFF" align=left>
        <td>
        Fri Jul  6 08:52:58 2012 <!-- 1168862s up -->
        </td>
        </tr>

    </table>
    <!-- /heading table -->

    <br>

    <!-- individual control table -->
    <table width="100%" align=center border=0 cellspacing=1 cellpadding=3>

        <tr>
        <td bgcolor="#DDDDFF" colspan=5 align=left>
        Individual Control
        </td>
        </tr>

        <!-- heading rows -->
        <tr bgcolor="#DDDDDD">
        <th>#</th>
        <th align=left>Name</th>
        <th align=left>State</th>
        <th align=left colspan=2>Action</th>
        </tr>
        <!-- /heading rows -->




<tr bgcolor="#F4F4F4"><td align=center>1</td>
<td>Lights</td><td>
<b><font color=green>ON</font></b></td><td>
<a onclick="return confirm('You are going to switch Outlet 1 [Lights] OFF. Continue?')" href=outlet?1=OFF>Switch OFF</a>
</td><td>
<a onclick="return confirm('You are going to cycle Outlet 1 [Lights]. Continue?')" href=outlet?1=CCL>Cycle</a>
</td></tr>


<tr bgcolor="#F4F4F4"><td align=center>2</td>
<td>Microwave</td><td>
<b><font color=green>ON</font></b></td><td>
<a onclick="return confirm('You are going to switch Outlet 2 [Microwave] OFF. Continue?')" href=outlet?2=OFF>Switch OFF</a>
</td><td>
<a onclick="return confirm('You are going to cycle Outlet 2 [Microwave]. Continue?')" href=outlet?2=CCL>Cycle</a>
</td></tr>


<tr bgcolor="#F4F4F4"><td align=center>3</td>
<td>NETHD</td><td>
<b><font color=green>ON</font></b></td><td>
<a onclick="return confirm('You are going to switch Outlet 3 [NETHD] OFF. Continue?')" href=outlet?3=OFF>Switch OFF</a>
</td><td>
<a onclick="return confirm('You are going to cycle Outlet 3 [NETHD]. Continue?')" href=outlet?3=CCL>Cycle</a>
</td></tr>


<tr bgcolor="#F4F4F4"><td align=center>4</td>
<td>WDTV</td><td>
<b><font color=green>ON</font></b></td><td>
<a onclick="return confirm('You are going to switch Outlet 4 [WDTV] OFF. Continue?')" href=outlet?4=OFF>Switch OFF</a>
</td><td>
<a onclick="return confirm('You are going to cycle Outlet 4 [WDTV]. Continue?')" href=outlet?4=CCL>Cycle</a>
</td></tr>


<tr bgcolor="#F4F4F4"><td align=center>5</td>
<td>PS3</td><td>
<b><font color=green>ON</font></b></td><td>
<a onclick="return confirm('You are going to switch Outlet 5 [PS3] OFF. Continue?')" href=outlet?5=OFF>Switch OFF</a>
</td><td>
<a onclick="return confirm('You are going to cycle Outlet 5 [PS3]. Continue?')" href=outlet?5=CCL>Cycle</a>
</td></tr>


<tr bgcolor="#F4F4F4"><td align=center>6</td>
<td>Popcorn Popper</td><td>
<b><font color=green>ON</font></b></td><td>
<a onclick="return confirm('You are going to switch Outlet 6 [Popcorn Popper] OFF. Continue?')" href=outlet?6=OFF>Switch OFF</a>
</td><td>
<a onclick="return confirm('You are going to cycle Outlet 6 [Popcorn Popper]. Continue?')" href=outlet?6=CCL>Cycle</a>
</td></tr>


<tr bgcolor="#F4F4F4"><td align=center>7</td>
<td>ITACH</td><td>
<b><font color=green>ON</font></b></td><td>
<a onclick="return confirm('You are going to switch Outlet 7 [ITACH] OFF. Continue?')" href=outlet?7=OFF>Switch OFF</a>
</td><td>
<a onclick="return confirm('You are going to cycle Outlet 7 [ITACH]. Continue?')" href=outlet?7=CCL>Cycle</a>
</td></tr>


<tr bgcolor="#F4F4F4"><td align=center>8</td>
<td>Life Support</td><td>
<b><font color=green>ON</font></b></td><td>
<a onclick="return confirm('You are going to switch Outlet 8 [Life Support] OFF. Continue?')" href=outlet?8=OFF>Switch OFF</a>
</td><td>
<a onclick="return confirm('You are going to cycle Outlet 8 [Life Support]. Continue?')" href=outlet?8=CCL>Cycle</a>
</td></tr>


    </table>
    <!-- /individual control table -->

    <br>

<table width="100%" align=center border=0 cellspacing=1 cellpadding=3>
<tr><td bgcolor="#DDDDFF" align=left>Master Control</td></tr>

<tr><td bgcolor="#F4F4F4" align=left><a onclick="return confirm('You are going to switch all Outlets OFF. Continue?')" href=outlet?a=OFF>All Outlets OFF</a></td></tr>
<tr><td bgcolor="#F4F4F4" align=left><a href=outlet?a=ON>All Outlets ON</a></td></tr>
<tr><td bgcolor="#F4F4F4" align=left><a onclick="return confirm('You are going to cycle all Outlets. Continue?')" href=outlet?a=CCL>Cycle all Outlets</a></td></tr>
<tr><td align=center>Sequence delay: 15 sec.</td></tr>

</table>


</td>
</tr>
</table>

</body>
</html>
"""
URLS={'index.htm':OFF_HTML,'outlet?1=OFF':OFF_HTML,'outlet?1=ON':ON_HTML}

def mock_response(req):
    url= req.get_full_url().split('/')[-1]
    if url in URLS.keys():
        resp = urllib2.addinfourl(StringIO.StringIO(URLS[url]), "mock message", req.get_full_url())
        resp.code = 200
        resp.msg = "OK"
        return resp

class MyHTTPHandler(urllib2.HTTPHandler):
    def http_open(self, req):
        return mock_response(req)

class TestPowerswitch(unittest.TestCase):
    def setUp(self):
        """ Set up the mock objects to do our unit tests """
        my_opener = urllib2.build_opener(MyHTTPHandler)
        urllib2.install_opener(my_opener)
        self.p=dlipower.powerswitch(hostname='http://lpc.digital-loggers.com')

    def test_status(self):
        """ Test the status method of the powerswitch object """
        URLS['index.htm']=OFF_HTML
        status=self.p.status(1)
        self.assertEqual(status, 'OFF')

    def test_off(self):
        """ Test the status method of the powerswitch object """
        self.p.off(1)
        URLS['index.htm']=OFF_HTML
        status=self.p.status(1)
        self.assertEqual(status, 'OFF')

    def test_on(self):
        """ Test the status method of the powerswitch object """
        self.p.on(1)
        URLS['index.htm']=ON_HTML
        status=self.p.status(1)
        self.assertEqual(status, 'ON')

def tearDown(self):
        """ Clean up the Mock objects """
        pass

if __name__ == '__main__':
    unittest.main()


#!/usr/bin/python
###############################################################
# Digital Loggers Web Power Switch management example
###############################################################
# Version: 0.01
# Description: Simple script to show how to use the DLI module
# Author: Dwight Hubbard d@dhub.me
# Copyright: This module may be used for any use personal
#            or commercial as long as the author and copyright
#            notice are included in full.
###############################################################
import sys,time

# The module needs to be in the python path.  So we'll add the
# current directory so we can find the dli module
sys.path.append('.')

#import the DLI module
import dlipower

# Global settings
# Change these to match the settings on the switch
SWITCHIP="192.168.0.100"
USER="admin"
PASSWORD="4321"

# Open (connect) to the power switch, if the
# parameters are not passed it defaults to the
# IP address, user and password the switch is 
# set with from the factory.  Only changed items
# actually need to be passed.
switch=dlipower.powerswitch(hostname=SWITCHIP,userid=USER,password=PASSWORD)

# Verify we can talk to the switch
if not switch.verify():
  print "Can't talk to the switch"
  sys.exit(1)

# Print the current state of all the outlets
switch.printstatus()
  
# Power on outlet #8
switch.on(8)

# Get the state of outlet 8 is and print it
print 'Outlet #8 is',switch.status(8)

# Wait a few seconds
time.sleep(5)

# Power outlet #8 back off
switch.off(8)

# Print the current state outlet 8 again
print 'Outlet #8 is',switch.status(8)



import os
from setuptools import setup

setup(
  name="dlipower",
  version="0.2.15",
  author="Dwight Hubbard",
  author_email="dwight@dwighthubbard.com",
  url="http://pypi.python.org/pypi/dlipower/",
  license="LICENSE.txt",
  packages=["dlipower",],
  scripts=["example.py","dlipower/dlipower.py"],
  long_description=open('README.txt').read(),
  description="Control digital loggers web power switch",
  requires=["BeautifulSoup"],
)
